@@ -10,9 +10,9 @@ import (
 	"sync"
 	"time"
 
-	"k8s.io/klog"
 	"github.com/prometheus/client_golang/prometheus"
 	"golang.org/x/time/rate"
+	"k8s.io/klog"
 
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/errors"
@@ -455,7 +455,7 @@ func (w *SyncWorker) syncOnce(ctx context.Context, work *SyncWork, maxWorkers in
 
 	// cache the payload until the release image changes
 	validPayload := w.payload
-	if validPayload == nil || !equalUpdate(configv1.Update{Image: validPayload.ReleaseImage}, update) {
+	if validPayload == nil || !equalUpdate(configv1.Update{Image: validPayload.ReleaseImage}, configv1.Update{Image: update.Image}) {
 		klog.V(4).Infof("Loading payload")
 		reporter.Report(SyncWorkerStatus{
 			Generation:  work.Generation,
@@ -545,17 +545,22 @@ func (w *SyncWorker) apply(ctx context.Context, payloadUpdate *payload.Update, w
 	graph.Split(payload.SplitOnJobs)
 	switch work.State {
 	case payload.InitializingPayload:
-		// create every component in parallel to maximize reaching steady
-		// state
+		// Create every component in parallel to maximize reaching steady
+		// state.
 		graph.Parallelize(payload.FlattenByNumberAndComponent)
 		maxWorkers = len(graph.Nodes)
 	case payload.ReconcilingPayload:
-		// run the graph in random order during reconcile so that we don't
+		// Run the graph in random order during reconcile so that we don't
 		// hang on any particular component - we seed from the number of
 		// times we've attempted this particular payload, so a particular
-		// payload always syncs in a reproducible order
-		r := rand.New(rand.NewSource(int64(work.Attempt)))
-		graph.Parallelize(payload.PermuteOrder(payload.FlattenByNumberAndComponent, r))
+		// payload always syncs in a reproducible order. We permute the
+		// same way for 8 successive attempts, shifting the tasks for each
+		// of those attempts to try to cover as much of the payload as
+		// possible within that interval.
+		steps := 8
+		epoch, iteration := work.Attempt/steps, work.Attempt%steps
+		r := rand.New(rand.NewSource(int64(epoch)))
+		graph.Parallelize(payload.ShiftOrder(payload.PermuteOrder(payload.FlattenByNumberAndComponent, r), iteration, steps))
 		maxWorkers = 2
 	default:
 		// perform an orderly roll out by payload order, using some parallelization
@@ -676,7 +681,7 @@ func (r *consistentReporter) Errors(errs []error) error {
 func (r *consistentReporter) CancelError() error {
 	r.lock.Lock()
 	defer r.lock.Unlock()
-	return errCanceled{fmt.Errorf("update was cancelled at %d/%d", r.done, r.total)}
+	return errCanceled{fmt.Errorf("update was cancelled at %d of %d", r.done, r.total)}
 }
 
 func (r *consistentReporter) Complete() {
@@ -737,7 +742,7 @@ func summarizeTaskGraphErrors(errs []error) error {
 		for _, err := range errs {
 			if uErr, ok := err.(*payload.UpdateError); ok {
 				if uErr.Task != nil {
-					klog.Infof("Update error %d/%d: %s %s (%T: %v)", uErr.Task.Index, uErr.Task.Total, uErr.Reason, uErr.Message, uErr.Nested, uErr.Nested)
+					klog.Infof("Update error %d of %d: %s %s (%T: %v)", uErr.Task.Index, uErr.Task.Total, uErr.Reason, uErr.Message, uErr.Nested, uErr.Nested)
 				} else {
 					klog.Infof("Update error: %s %s (%T: %v)", uErr.Reason, uErr.Message, uErr.Nested, uErr.Nested)
 				}
@@ -751,12 +756,44 @@ func summarizeTaskGraphErrors(errs []error) error {
 	if len(errs) == 1 {
 		return errs[0]
 	}
+	// hide the generic "not available yet" when there are more specific errors present
+	if filtered := filterErrors(errs, isClusterOperatorNotAvailable); len(filtered) > 0 {
+		return newMultipleError(filtered)
+	}
+	// if we're only waiting for operators, condense the error down to a singleton
 	if err := newClusterOperatorsNotAvailable(errs); err != nil {
 		return err
 	}
 	return newMultipleError(errs)
 }
 
+// filterErrors returns only the errors in errs which are false for all fns.
+func filterErrors(errs []error, fns ...func(err error) bool) []error {
+	var filtered []error
+	for _, err := range errs {
+		if errorMatches(err, fns...) {
+			continue
+		}
+		filtered = append(filtered, err)
+	}
+	return filtered
+}
+
+func errorMatches(err error, fns ...func(err error) bool) bool {
+	for _, fn := range fns {
+		if fn(err) {
+			return true
+		}
+	}
+	return false
+}
+
+// isClusterOperatorNotAvailable returns true if this is a ClusterOperatorNotAvailable error
+func isClusterOperatorNotAvailable(err error) bool {
+	uErr, ok := err.(*payload.UpdateError)
+	return ok && uErr != nil && uErr.Reason == "ClusterOperatorNotAvailable"
+}
+
 // newClusterOperatorsNotAvailable unifies multiple ClusterOperatorNotAvailable errors into
 // a single error. It returns nil if the provided errors are not of the same type.
 func newClusterOperatorsNotAvailable(errs []error) error {
